@@ -140,15 +140,22 @@ net_virtual_device_add_to_notebook (NetObject *object,
 {
         NetVirtualDevice *virtual_device = NET_VIRTUAL_DEVICE (object);
         GtkWidget *widget;
+        GtkWindow *window;
 
         /* add widgets to size group */
         widget = GTK_WIDGET (gtk_builder_get_object (virtual_device->priv->builder,
                                                      "heading_ipv4"));
         gtk_size_group_add_widget (heading_size_group, widget);
 
+        /* reparent */
+        window = GTK_WINDOW (gtk_builder_get_object (virtual_device->priv->builder,
+                                                     "window_tmp"));
         widget = GTK_WIDGET (gtk_builder_get_object (virtual_device->priv->builder,
                                                      "vbox6"));
+        g_object_ref (widget);
+        gtk_container_remove (GTK_CONTAINER (window), widget);
         gtk_notebook_append_page (notebook, widget, NULL);
+        g_object_unref (widget);
         return widget;
 }
 
@@ -461,6 +468,7 @@ net_virtual_device_add_row (NetVirtualDevice *virtual_device,
         value = gtk_label_new (NULL);
         gtk_misc_set_alignment (GTK_MISC (value), 0.0, 0.5);
         g_object_bind_property (virtual_device, property_name, value, "label", 0);
+        gtk_label_set_mnemonic_widget (GTK_LABEL (label), value);
         gtk_grid_attach (grid, value, 1, top_attach, 1, 1);
         gtk_widget_show (value);
 }
